==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/engine/poller_helper.php <==
<?
/* Poller Helper
 * Copyright (C) <2004> Javier Szyszlican <javier@szysz.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

    $jffnms_functions_include="engine";
    include_once("../conf/config.php");
    
    $poller_helper_time = time_usec();
    
    $my_sat_id = satellite_my_id();

    $jffnms_poller_command = "poller.php";

    $query_hosts="SELECT * FROM hosts WHERE id > 1 AND poll > 0 AND satellite = $my_sat_id";
    $result_hosts = db_query ($query_hosts) or die ("Query failed - R2 - ".db_error());

    while ($host = db_fetch_array($result_hosts)) {
    
	$host_id = $host["id"];

	// Poll DMIIs
        // ----------

	if ($host["dmii"]!=1) { 
	    logger(" :  H ".str_pad($host["id"],3," ",STR_PAD_LEFT)." : Polling DMIIs.\n");
	    spawn ("$php_executable -q poller.php","$host_id dmii",1);
	    sleep(2);
	}
	
	// Poll Alarmed Interfaces
        // -----------------------
    
	$alarms = alarms_list(0,array("alarm_state"=>ALARM_DOWN,"host"=>$host["id"]));

	unset ($interface_id);
	foreach ( $alarms as $alarm ) { //get all the interface ids from this host
	    $int = current(interfaces_list ($alarm["interface"]));
	    if ($int["poll"] > 0)
		$interface_id[]=$alarm["interface"];
	}
	
	if (count($interface_id) > 0) {
	    logger( " :  H ".str_pad($host["id"],3," ",STR_PAD_LEFT)." : Polling Alarmed/Down: ".count($interface_id)." Interfaces.\n");
	    
	    spawn ("$php_executable -q poller.php","$host_id ".join(",",$interface_id),1);
	    sleep(5);
	}
    }

    $poller_helper_time = time_usec_diff($poller_helper_time);
    logger(" : Poller Helper Ended, Total Time: $poller_helper_time msec.\n");
?>

==> jffnms_0.8.3dfsg.1.orig.tar.gz: jffnms-0.8.3dfsg.1/engine/poller_helper.php <==
<?
/* Poller Helper. This file is part of JFFNMS
 * Copyright (C) <2004> Javier Szyszlican <javier@szysz.com>
 * This program is licensed under the GNU GPL, full terms in the LICENSE file
 */

    $jffnms_functions_include="engine";
    include_once("../conf/config.php");
    
    $poller_helper_time = time_usec();
    
    $my_sat_id = satellite_my_id();

    $jffnms_poller_command = "poller.php";

    $query_hosts="SELECT * FROM hosts WHERE id > 1 AND poll > 0 AND satellite = $my_sat_id";
    $result_hosts = db_query ($query_hosts) or die ("Query failed - R2 - ".db_error());

    while ($host = db_fetch_array($result_hosts)) {
    
	$host_id = $host["id"];

	// Poll DMIIs
        // ----------

	if ($host["dmii"]!=1) { 
	    logger(" :  H ".str_pad($host["id"],3," ",STR_PAD_LEFT)." : Polling DMIIs.\n");
	    spawn ("$php_executable -q poller.php","$host_id dmii",1);
	    sleep(2);
	}
	
	// Poll Alarmed Interfaces
        // -----------------------
    
	$alarms = alarms_list(0,array("alarm_state"=>ALARM_DOWN,"host"=>$host["id"]));

	unset ($interface_id);
	foreach ( $alarms as $alarm ) { //get all the interface ids from this host
	    $int = current(interfaces_list ($alarm["interface"]));
	    if ($int["poll"] > 0)
		$interface_id[]=$alarm["interface"];
	}
	
	if (count($interface_id) > 0) {
	    logger( " :  H ".str_pad($host["id"],3," ",STR_PAD_LEFT)." : Polling Alarmed/Down: ".count($interface_id)." Interfaces.\n");
	    
	    spawn ("$php_executable -q poller.php","$host_id ".join(",",$interface_id),1);
	    sleep(5);
	}
    }

    $poller_helper_time = time_usec_diff($poller_helper_time);
    logger(" : Poller Helper Ended, Total Time: $poller_helper_time msec.\n");
?>
